@@ -1,6 +1,8 @@
 from django_hosts import patterns, host
 
 host_patterns = patterns('',
+    host(r'example\.com', 'django_hosts.tests.urls.simple',
+         name='without_www'),
     host(r'www\.example\.com', 'django_hosts.tests.urls.simple', name='www'),
     host(r'static', 'django_hosts.tests.urls.simple', name='static'),
     host(r'^s(?P<subdomain>\w+)', 'django_hosts.tests.urls.complex',
